@@ -18,7 +18,7 @@
 
 // KDE
 #include <KActionCollection>
-#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
+#if HAVE_DBUS
 #include <KGlobalAccel>
 #endif
 #include <KLocalizedString>
@@ -92,7 +92,9 @@ void Application::populateCommandLineParser(QCommandLineParser *parser)
     // the title and overriding whatever is set elsewhere.
     // https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=532029
     // https://www.debian.org/doc/debian-policy/ch-customized-programs.html#s11.8.3
-    auto titleOption = QCommandLineOption({QStringLiteral("T")}, QStringLiteral("Debian policy compatibility, not used"), QStringLiteral("value"));
+    // --title is used by the VirtualBox Guest Additions installer
+    auto titleOption =
+        QCommandLineOption({QStringLiteral("T"), QStringLiteral("title")}, QStringLiteral("Debian policy compatibility, not used"), QStringLiteral("value"));
     titleOption.setFlags(QCommandLineOption::HiddenFromHelp);
     parser->addOption(titleOption);
 }
@@ -507,7 +509,7 @@ void Application::startBackgroundMode(MainWindow *window)
         return;
     }
 
-#if !defined(Q_OS_WIN) && !defined(Q_OS_MACOS)
+#if HAVE_DBUS
     KActionCollection *collection = window->actionCollection();
     QAction *action = collection->addAction(QStringLiteral("toggle-background-window"));
     action->setObjectName(QStringLiteral("Konsole Background Mode"));
