@@ -31,25 +31,13 @@ class ViewProperties;
  * A re-usable terminal emulator component using the KParts framework which can
  * be used to embed terminal emulators into other applications.
  */
-#if USE_TERMINALINTERFACEV2
-class Part : public KParts::ReadOnlyPart, public TerminalInterfaceV2
-{
-    Q_OBJECT
-    Q_INTERFACES(TerminalInterface TerminalInterfaceV2)
-#else
-class TerminalInterfaceV2;
 class Part : public KParts::ReadOnlyPart, public TerminalInterface
 {
     Q_OBJECT
     Q_INTERFACES(TerminalInterface)
-#endif
 public:
     /** Constructs a new Konsole part with the specified parent. */
-#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
     explicit Part(QObject *parent, const QVariantList &);
-#else
-    explicit Part(QWidget *parentWidget, QObject *parent, const QVariantList &);
-#endif
     ~Part() override;
 
     /** Reimplemented from TerminalInterface. */
@@ -71,7 +59,6 @@ public:
     /** Reimplemented from TerminalInterface. */
     QString currentWorkingDirectory() const override;
 
-#if USE_TERMINALINTERFACEV2
     /** Reimplemented from TerminalInterfaceV2 */
     QStringList availableProfiles() const override;
 
@@ -83,7 +70,6 @@ public:
 
     /** Reimplemented from TerminalInterfaceV2 */
     QVariant profileProperty(const QString &profileProperty) const override;
-#endif
 
 public Q_SLOTS:
     /**
