@@ -27,10 +27,13 @@
 // KDE
 #include <KAboutData>
 #include <KCrash>
-#include <KDBusService>
 #include <KIconTheme>
 #include <KLocalizedString>
 
+#if HAVE_DBUS
+#include <KDBusService>
+#endif
+
 #define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
 #if HAVE_STYLE_MANAGER
 #include <KStyleManager>
@@ -54,6 +57,7 @@ bool shouldUseNewProcess(int argc, char *argv[]);
 // restore sessions saved by KDE.
 void restoreSession(Application &app);
 
+#if HAVE_DBUS
 // Workaround for a bug in KDBusService: https://bugs.kde.org/show_bug.cgi?id=355545
 // It calls exit(), but the program can't exit before the QApplication is deleted:
 // https://bugreports.qt.io/browse/QTBUG-48709
@@ -64,6 +68,7 @@ void deleteQApplication()
         delete qApp;
     }
 }
+#endif
 
 // This override resolves following problem: since some qt version if
 // XDG_CURRENT_DESKTOP ≠ kde, then pressing and immediately releasing Alt
@@ -141,15 +146,7 @@ int main(int argc, char *argv[])
     KIconTheme::initTheme();
 #endif
 
-    /**
-     * enable dark mode for title bar on Windows
-     */
-#if defined(Q_OS_WIN)
-    if (!qEnvironmentVariableIsSet("QT_QPA_PLATFORM")) {
-        qputenv("QT_QPA_PLATFORM", "windows:darkmode=1");
-    }
-#endif
-
+#if HAVE_DBUS
     // Check if any of the arguments makes it impossible to re-use an existing process.
     // We need to do this manually and before creating a QApplication, because
     // QApplication takes/removes the Qt specific arguments that are incompatible.
@@ -157,6 +154,7 @@ int main(int argc, char *argv[])
     if (!needNewProcess) { // We need to avoid crashing
         needToDeleteQApplication = true;
     }
+#endif
 
     auto app = new QApplication(argc, argv);
 
@@ -210,6 +208,7 @@ int main(int argc, char *argv[])
     parser->process(args);
     about.processCommandLine(parser.data());
 
+#if HAVE_DBUS
     /// ! DON'T TOUCH THIS ! ///
     const KDBusService::StartupOption startupOption =
         Konsole::KonsoleSettings::useSingleInstance() && !needNewProcess ? KDBusService::Unique : KDBusService::Multiple;
@@ -224,14 +223,17 @@ int main(int argc, char *argv[])
     KDBusService dbusService(startupOption | KDBusService::NoExitOnFailure);
 
     needToDeleteQApplication = false;
+#endif
 
     // If we reach this location, there was no existing copy of Konsole
     // running, so create a new instance.
     Application konsoleApp(parser, customCommand);
 
+#if HAVE_DBUS
     // The activateRequested() signal is emitted when a second instance
     // of Konsole is started.
     QObject::connect(&dbusService, &KDBusService::activateRequested, &konsoleApp, &Application::slotActivateRequested);
+#endif
 
     if (app->isSessionRestored()) {
         restoreSession(konsoleApp);
@@ -284,7 +286,7 @@ bool shouldUseNewProcess(int argc, char *argv[])
     QStringList qtProblematicOptions;
     qtProblematicOptions << QStringLiteral("--session") << QStringLiteral("--name") << QStringLiteral("--reverse") << QStringLiteral("--stylesheet")
                          << QStringLiteral("--graphicssystem");
-#if HAVE_X11
+#if WITH_X11
     qtProblematicOptions << QStringLiteral("--display") << QStringLiteral("--visual");
 #endif
     for (const QString &option : std::as_const(qtProblematicOptions)) {
@@ -296,7 +298,7 @@ bool shouldUseNewProcess(int argc, char *argv[])
     // take KDE options into consideration
     QStringList kdeProblematicOptions;
     kdeProblematicOptions << QStringLiteral("--config") << QStringLiteral("--style");
-#if HAVE_X11
+#if WITH_X11
     kdeProblematicOptions << QStringLiteral("--waitforwm");
 #endif
 
